GrpcSourceBuilder

Struct GrpcSourceBuilder 

pub struct GrpcSourceBuilder { /* private fields */ }
Builder for gRPC sources.

Provides a fluent API for constructing gRPC sources with sensible defaults.

Example

use drasi_source_grpc::GrpcSource;

let source = GrpcSource::builder("my-grpc-source")
    .with_host("0.0.0.0")
    .with_port(50051)
    .build()?;

Implementations

Source

impl GrpcSourceBuilder

pub fn new(id: impl Into<String>) -> Self

Create a new gRPC source builder with the given ID and default values

pub fn with_host(self, host: impl Into<String>) -> Self

Set the gRPC host

pub fn with_port(self, port: u16) -> Self

Set the gRPC port

pub fn with_endpoint(self, endpoint: impl Into<String>) -> Self

Set the optional service endpoint

pub fn with_timeout_ms(self, timeout_ms: u64) -> Self

Set the request timeout in milliseconds

pub fn with_dispatch_mode(self, mode: DispatchMode) -> Self

Set the dispatch mode for this source

pub fn with_dispatch_buffer_capacity(self, capacity: usize) -> Self

Set the dispatch buffer capacity for this source

pub fn with_bootstrap_provider( self, provider: impl BootstrapProvider + 'static, ) -> Self

Set the bootstrap provider for this source

pub fn with_auto_start(self, auto_start: bool) -> Self

Set whether this source should auto-start when DrasiLib starts.

Default is true. Set to false if this source should only be started manually via start_source().

pub fn with_config(self, config: GrpcSourceConfig) -> Self

Set the full configuration at once

pub fn build(self) -> Result<GrpcSource>

Build the gRPC source

Errors

Returns an error if the source cannot be constructed.